@@ -1,7 +1,7 @@
 use super::graph::Required;
 use crate::{id::Id, modules::sort::graph::StmtDepGraph};
 use indexmap::IndexSet;
-use petgraph::EdgeDirection::{Incoming as Dependants, Outgoing as Dependancies};
+use petgraph::EdgeDirection::{Incoming as Dependants, Outgoing as Dependencies};
 use std::{collections::VecDeque, iter::from_fn, ops::Range};
 use swc_atoms::js_word;
 use swc_common::{
@@ -181,7 +181,7 @@ fn iter<'a>(
             // We
             {
                 let deps = graph
-                    .neighbors_directed(idx, Dependancies)
+                    .neighbors_directed(idx, Dependencies)
                     .filter(|dep| {
                         let declared_in_same_module = match &current_range {
                             Some(v) => v.contains(&dep),
@@ -197,7 +197,7 @@ fn iter<'a>(
                             }
                         }
 
-                        // Exlcude emitted items
+                        // Exclude emitted items
                         !done.contains(dep)
                     })
                     .collect::<Vec<_>>();
@@ -267,7 +267,7 @@ fn iter<'a>(
                     // dbg!(&dependants);
 
                     // We only emit free items because we want to emit statements from same module
-                    // to emitted closedly.
+                    // to emitted closely.
                     for dependant in dependants {
                         if !done.contains(&dependant) && free.contains(&dependant) {
                             stack.push_front(dependant);
@@ -307,7 +307,7 @@ fn iter<'a>(
                 // dbg!(&dependants);
 
                 // We only emit free items because we want to emit statements from same module
-                // to emitted closedly.
+                // to emitted closely.
                 for dependant in dependants {
                     if !done.contains(&dependant) && free.contains(&dependant) {
                         stack.push_front(dependant);
@@ -506,7 +506,7 @@ impl Visit for InitializerFinder {
 /// We do not care about variables created by current statement.
 /// But we care about modifications.
 #[derive(Default)]
-struct RequirementCalculartor {
+struct RequirementCalculator {
     required_ids: IndexSet<(Id, Required), ahash::RandomState>,
     /// While bundling, there can be two bindings with same name and syntax
     /// context, in case of wrapped es modules. We exclude them from dependency
@@ -531,7 +531,7 @@ macro_rules! weak {
     };
 }
 
-impl RequirementCalculartor {
+impl RequirementCalculator {
     fn insert(&mut self, i: Id) {
         self.required_ids.insert((
             i,
@@ -544,7 +544,7 @@ impl RequirementCalculartor {
     }
 }
 
-impl Visit for RequirementCalculartor {
+impl Visit for RequirementCalculator {
     noop_visit_type!();
 
     weak!(visit_arrow_expr, ArrowExpr);
@@ -642,7 +642,7 @@ fn calc_deps(new: &[ModuleItem]) -> StmtDepGraph {
 
         // We start by calculating ids created by statements. Note that we don't need to
         // analyze bodies of functions nor members of classes, because it's not
-        // evaludated until they are called.
+        // evaluated until they are called.
 
         match item {
             // We only check declarations because ids are created by declarations.
@@ -736,10 +736,10 @@ fn calc_deps(new: &[ModuleItem]) -> StmtDepGraph {
 
     for (idx, item) in new.iter().enumerate() {
         // We then calculate which ids a statement require to be executed.
-        // Again, we don't need to analyze non-top-level idents because they
-        // are not evaluated while lpoading module.
+        // Again, we don't need to analyze non-top-level identifiers because they
+        // are not evaluated while loading module.
 
-        let mut visitor = RequirementCalculartor::default();
+        let mut visitor = RequirementCalculator::default();
 
         item.visit_with(&Invalid { span: DUMMY_SP }, &mut visitor);
 
@@ -772,7 +772,7 @@ fn calc_deps(new: &[ModuleItem]) -> StmtDepGraph {
                         // );
                         if cfg!(debug_assertions) {
                             let deps: Vec<_> =
-                                graph.neighbors_directed(idx, Dependancies).collect();
+                                graph.neighbors_directed(idx, Dependencies).collect();
                             assert!(deps.contains(&declarator_index));
                         }
                     }
@@ -786,7 +786,7 @@ fn calc_deps(new: &[ModuleItem]) -> StmtDepGraph {
 
 #[cfg(test)]
 mod tests {
-    use super::{calc_deps, Dependancies};
+    use super::{calc_deps, Dependencies};
     use crate::{bundler::tests::suite, debug::print_hygiene};
     use swc_common::DUMMY_SP;
     use swc_ecma_ast::*;
@@ -806,7 +806,7 @@ mod tests {
                 }
 
                 let deps = graph
-                    .neighbors_directed(i, Dependancies)
+                    .neighbors_directed(i, Dependencies)
                     .collect::<Vec<_>>();
 
                 for dep in deps {
